@@ -4,8 +4,8 @@ import argparse
 if __name__ == '__main__':
 	parser = argparse.ArgumentParser(description='Configure NatEx local installation using the `setup` sub-command')
 	parser.add_argument('command', help='setup')
-	parser.add_argument('param', metavar='N', nargs='+')
+	parser.add_argument('params', metavar='N', nargs='+')
 	args = parser.parse_args()
 
 	if args.command == 'setup':
-		NatEx.setup(*args.param)
\ No newline at end of file
+		NatEx.setup(*args.params)
\ No newline at end of file
