@@ -344,7 +344,7 @@ def natex(sentence, language_code='en'):
 					needs_setup = True
 		
 		if needs_setup:
-			print('Download of stanza models necessary. Please re-run the script once the installation is done!')
+			print('Download of stanza models necessary. You will have to re-run the script once the downloads are through.')
 			NatEx.setup(language_code)
 			return natex(sentence, language_code)
 
